cheesecake.model.Documentable

Package cheesecake :: Module model :: Class Documentable |
[show private | hide private]
[frames | no frames]

## Type Documentable

    object --+
             |
            Documentable

Known Subclasses:
  `Class`, `Function`, `Module`, `Package`

Method Summary
| `__init__(self, system, prefix, name, docstring, parent)`
| `__getstate__(self)`
| `__repr__(self)`
| `dottedNameToFullName(self, dottedname)`
| `fullName(self)`
| `name2fullname(self, name)`
| `resolveDottedName(self, dottedname, verbose)`
| `setup(self)`
| `shortdocstring(self)`
Inherited from object
| ``__delattr__`(...)` x.__delattr__('name') <==> del x.name
| ``__getattribute__`(...)` x.__getattribute__('name') <==> x.name
| ``__hash__`(x)` x.__hash__() <==> hash(x)
| ``__new__`(T, S, ...)` T.__new__(S, ...) -> a new object with type S, a subtype of T
| ``__reduce__`(...)` helper for pickle
| ``__reduce_ex__`(...)` helper for pickle
| ``__setattr__`(...)` x.__setattr__('name', value) <==> x.name = value
| ``__str__`(x)` x.__str__() <==> str(x)

Generated by Epydoc 2.1 on Fri Feb 9 02:15:13 2007 | http://epydoc.sf.net